@@ -104,6 +104,14 @@ class Serve(_BkServe):
 
     args = (
         tuple((arg, arg_obj) for arg, arg_obj in _BkServe.args if arg != '--dev') + (
+        ('--index-titles', Argument(
+            metavar="KEY=VALUE",
+            nargs='+',
+            help= ("Custom titles to use for Multi Page Apps specified as "
+                   "key=value pairs mapping from the application page slug"
+                   "to the title to show on the Multi Page App index page."
+                   ),
+        )),
         ('--static-dirs', Argument(
             metavar="KEY=VALUE",
             nargs='+',
@@ -115,6 +123,11 @@ class Serve(_BkServe):
             type   = str,
             help   = "Password or filepath to use with Basic Authentication."
         )),
+        ('--cookie-path', Argument(
+            action = 'store',
+            type   = str,
+            help   = "The path the cookies should apply to ."
+        )),
         ('--oauth-provider', Argument(
             action = 'store',
             type   = str,
@@ -375,6 +388,12 @@ class Serve(_BkServe):
                     "found."
                 )
 
+        # Handle custom titles for Multi Page Apps index
+        if args.index_titles:
+            for item in args.index_titles:
+                slug, title = item.split('=', 1)
+                config.index_titles[slug] = title
+
         # Handle tranquilized functions in the supplied functions
         if args.rest_provider in REST_PROVIDERS:
             pattern = REST_PROVIDERS[args.rest_provider](files, args.rest_endpoint)
@@ -575,6 +594,14 @@ class Serve(_BkServe):
         elif args.cookie_secret:
             config.cookie_secret = args.cookie_secret
 
+        if args.cookie_path and "PANEL_COOKIE_PATH" in os.environ:
+            raise ValueError(
+                "Supply cookie path either using environment "
+                "variable or via explicit argument, not both."
+            )
+        elif args.cookie_path:
+            config.cookie_path = args.cookie_path
+
         # Check only one auth is used.
         if args.oauth_provider and config.oauth_provider:
                 raise ValueError(
@@ -715,6 +742,9 @@ class Serve(_BkServe):
             elif args.oauth_jwt_user:
                 config.oauth_jwt_user = args.oauth_jwt_user
 
+        if config.cookie_path:
+            kwargs['cookie_path'] = config.cookie_path
+
         if config.cookie_secret:
             kwargs['cookie_secret'] = config.cookie_secret
 
