@@ -157,7 +157,7 @@ def find_module_bundles(module_spec: str) -> dict[pathlib.Path, list[type[Reacti
         module_file = module
     assert module_file is not None
 
-    bundles = defaultdict(list)
+    bundles: defaultdict[pathlib.Path, list[type[ReactiveESM]]] = defaultdict(list)
     module_path = pathlib.Path(module_file).parent
     for component in components:
         if component._bundle:
@@ -166,12 +166,13 @@ def find_module_bundles(module_spec: str) -> dict[pathlib.Path, list[type[Reacti
                 path = (module_path / bundle_path).absolute()
             else:
                 path = bundle_path.absolute()
-            bundles[path].append(component)
         elif len(components) > 1 and not classes:
             component_module = module_name or component.__module__
-            bundles[module_path / f'{component_module}.bundle.js'].append(component)
+            path = module_path / f'{component_module}.bundle.js'
         else:
-            bundles[component._module_path / f'{component.__name__}.bundle.js'].append(component)
+            path = component._module_path / f'{component.__name__}.bundle.js'
+        if component not in bundles[path]:
+            bundles[path].append(component)
 
     return dict(bundles)
 
@@ -406,20 +407,25 @@ def generate_project(
     shared_modules = {}
     index = ''
     for component in components:
+        try:
+            esm_path = component._esm_path(compiled='compiling')
+        except Exception:
+            esm_path = None
         name = component.__name__
-        esm_path = component._esm_path(compiled=False)
         if esm_path:
+            imprt = esm_path.stem
             ext = esm_path.suffix.lstrip('.')
         else:
+            imprt = name
             ext = 'jsx' if issubclass(component, ReactComponent) else 'js'
         code, component_deps = extract_dependencies(component)
         # Detect default export in component code and handle import accordingly
         if _EXPORT_DEFAULT_RE.search(code):
-            index += f'import {name} from "./{name}"\n'
+            index += f'import {name} from "./{imprt}"\n'
         else:
-            index += f'import * as {name} from "./{name}"\n'
+            index += f'import * as {name} from "./{imprt}"\n'
 
-        with open(path / f'{name}.{ext}', 'w') as component_file:
+        with open(path / f'{imprt}.{ext}', 'w') as component_file:
             component_file.write(code)
         # TODO: Improve merging of dependencies
         dependencies.update(component_deps)
