@@ -448,7 +448,7 @@ class PanelCodeHandler(CodeHandler):
 
         if runner:
             self._runner = runner
-        elif source:
+        elif source is not None:
             self._runner = PanelCodeRunner(source, filename, argv, package=package)
         else:
             raise ValueError("Must provide source code to PanelCodeHandler")
