@@ -142,20 +142,36 @@ export class ColumnView extends BkColumnView {
   }
 
   override async update_children(): Promise<void> {
-    // Can be removed after https://github.com/bokeh/bokeh/pull/14459 is released
     const created = await this.build_child_views()
-    const created_children = new Set(created)
+    const created_views = new Set(created)
+
+    // Find index up to which the order of the existing views
+    // matches the order of the new views. This allows us to
+    // skip re-inserting the views up to this point
+    const current_views = Array.from(this.shadow_el.children).flatMap(el => {
+      const view = this.child_views.find(view => view.el === el)
+      return view === undefined ? [] : [view]
+    })
+    let matching_index = null
+    for (let i = 0; i < current_views.length; i++) {
+      if (current_views[i] === this.child_views[i]) {
+        matching_index = i
+      } else {
+        break
+      }
+    }
 
     // Since appending to a DOM node will move the node to the end if it has
     // already been added appending all the children in order will result in
-    // correct ordering
-    for (const child_view of this.child_views) {
-      const is_new = created_children.has(child_view)
-      const target = child_view.rendering_target() ?? this.shadow_el
+    // correct ordering.
+    for (let i = 0; i < this.child_views.length; i++) {
+      const view = this.child_views[i]
+      const is_new = created_views.has(view)
+      const target = view.rendering_target() ?? this.self_target
       if (is_new) {
-        child_view.render_to(target)
-      } else {
-        target.append(child_view.el)
+        view.render_to(target)
+      } else if (matching_index === null || i > matching_index) {
+        target.append(view.el)
       }
     }
 
