@@ -18,7 +18,7 @@ from ..io.resources import (
     JS_VERSION, ResourceComponent, component_resource_path, get_dist_path,
     resolve_custom_path,
 )
-from ..io.state import state
+from ..io.state import set_curdoc, state
 from ..util import relative_to
 
 if TYPE_CHECKING:
@@ -135,7 +135,13 @@ class Design(param.Parameterized, ResourceComponent):
                 if (old_models and model in old_models) or model in seen:
                     continue
                 seen.add(model)
-            self._apply_modifiers(o, ref, self.theme, isolated, cache, document)
+            if document:
+                # Theme hook may be applied during callback triggered from a different document
+                # we must set_curdoc to ensure style caches are not shared across documents
+                with set_curdoc(document):
+                    self._apply_modifiers(o, ref, self.theme, isolated, cache, document)
+            else:
+                self._apply_modifiers(o, ref, self.theme, isolated, cache, document)
 
     def _apply_hooks(self, viewable: Viewable, root: Model, changed: Viewable, old_models=None) -> None:
         from ..io.state import state
